@@ -50,6 +50,7 @@ class AugumentedClient(KazooClient):
         for c in self.get_children(path):
             full_path = os.path.join(path, c)
             value, _ = self.get(full_path)
+            value = value.decode("utf-8")
 
             if show_matches:
                 for line in value.split("\n"):
@@ -101,9 +102,10 @@ class AugumentedClient(KazooClient):
         for r in recs:
             try:
                 with connected_socket(r[4]) as s:
-                    s.send("%s\n" % (cmd))
+                    buf = "%s\n" % (cmd)
+                    s.send(buf.encode())
                     while True:
-                        b = s.recv(1024)
+                        b = s.recv(1024).decode("utf-8")
                         if b == "":
                             break
                         replies.append(b)
