@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
 
+import json
 import os
+import tempfile
+import shutil
 
 try:
     from StringIO import StringIO
@@ -34,10 +37,16 @@ class BasicCmdsTestCase(unittest.TestCase):
         self.output = StringIO()
         self.shell = Shell([self.zk_host], 5, self.output, setup_readline=False)
 
+        # Create an empty test dir (needed for some tests)
+        self.temp_dir = tempfile.mkdtemp()
+
     def tearDown(self):
         self.output = None
         self.shell = None
 
+        if os.path.isdir(self.temp_dir):
+            shutil.rmtree(self.temp_dir)
+
     def test_create_ls(self):
         self.shell.onecmd("create %s/one 'hello'" % (self.tests_path))
         self.shell.onecmd("ls %s" % (self.tests_path))
@@ -135,3 +144,32 @@ class BasicCmdsTestCase(unittest.TestCase):
         self.shell.onecmd("create %s 'HELLO' false false true" % (path))
         self.shell.onecmd("igrep %s hello true" % (self.tests_path))
         self.assertEqual("%s: HELLO\n" % (path), self.output.getvalue())
+
+    def test_cp_zk2zk(self):
+        src_path = "%s/src" % (self.tests_path)
+        dst_path = "%s/dst" % (self.tests_path)
+        self.shell.onecmd("create %s/nested/znode 'HELLO' false false true" % (src_path))
+        self.shell.onecmd("cp zk://%s%s zk://%s%s true true" % (
+            self.zk_host, src_path, self.zk_host, dst_path))
+        self.shell.onecmd("tree %s" % (dst_path))
+        expected_output = """.
+├── nested
+│   ├── znode
+"""
+        self.assertEqual(expected_output, self.output.getvalue())
+
+    def test_cp_zk2json(self):
+        src_path = "%s/src" % (self.tests_path)
+        json_file = "%s/backup.json" % (self.temp_dir)
+        self.shell.onecmd("create %s/nested/znode 'HELLO' false false true" % (src_path))
+        self.shell.onecmd("cp zk://%s%s json://%s/backup true true" % (
+            self.zk_host, src_path, json_file.replace("/", "!")))
+
+        with open(json_file, "r") as f:
+            copied_znodes = json.load(f)
+            copied_paths = copied_znodes.keys()
+
+        self.assertIn("/backup", copied_paths)
+        self.assertIn("/backup/nested", copied_paths)
+        self.assertIn("/backup/nested/znode", copied_paths)
+        self.assertEqual("HELLO", copied_znodes["/backup/nested/znode"]["content"])
